# Pyrabola

Pyrabola simulates the propagation of laser light through a system composed of planar mirrors, a parabolic mirror and a focal spot camera. It aims to balance speed with accuracy by clever use of approximations to the exact propagation solutions, which for example enable us to model the full evolution of an aberrated laser pulse through a tight focus, without placing particularly stringent constraints on resolution.

This code is a work in progress.
